@@ -12,12 +12,11 @@
 # Description:
 # Use Shell to do additional jobs after installation is done, mainly for upgrading.
 #
-
-echo "POST INSTALLATION: Remove old subsystem folder.."
+echo "POST INSTALLATION: Do something additional after installation.."
 
 SUB_SYSTEM_PATH=/opt/tandbergtv/cms/workflow/plugins/subsystems
 
-declare -a SUB_SYSTEM=("utilities" "variable-functions")
+declare -a SUB_SYSTEM=("cms-distribution")
 
 for ss in "${SUB_SYSTEM[@]}"
 do
@@ -31,11 +30,9 @@ do
 	fi
 done
 
-
 CMS_CLUSER_PROP=/opt/tandbergtv/cms/conf/workflow/cluster.properties
 PREPACK_CLUSER_PROP=/opt/tandbergtv/cms/conf/prepack/cluster.properties
 PREPACK_CLUSER_PROP_FOLDER=/opt/tandbergtv/cms/conf/prepack
-
 if [ -f "$CMS_CLUSER_PROP" ] 
 then
     echo "copying $CMS_CLUSER_PROP to $PREPACK_CLUSER_PROP"
@@ -48,5 +45,13 @@ else
     echo "$CMS_CLUSER_PROP does not exists!"
 fi
 
+CF_DATATYPE_MAPPING_DAT=/opt/tandbergtv/cms/plugins/content/com.tandbergtv.metadata/resources/cfDataTypeMapping.dat
+if [ -f "$CF_DATATYPE_MAPPING_DAT" ] 
+then
+    echo "remove $CF_DATATYPE_MAPPING_DAT"
+    rm -rf $CF_DATATYPE_MAPPING_DAT
+else
+    echo "$CF_DATATYPE_MAPPING_DAT does not exists!"
+fi
 
 echo "POST INSTALLATION: done.."
\ No newline at end of file
